@@ -6,6 +6,9 @@
 extern void protocol_fail(int e, const char* msg);
 extern void protocol_succ(const char* msg);
 
+extern const char* user;
+extern const char* pass;
+
 // This must be provided by the protocol, but will be set by the lib.
 extern int port;
 
